<?php

namespace FiloBlu\Flow\Model\From\Entity;

/**
 * Class Attribute
 * @package FiloBlu\Flow\Model\From\Entity
 */
class Attribute extends AbstractEntity
{
    /**
     * @var \Magento\Eav\Model\ConfigFactory
     */
    protected $configFactory;

    /**
     * Attribute constructor.
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Catalog\Model\ProductFactory $productFactory
     * @param \FiloBlu\Flow\Helper\Product $helperProduct
     * @param \FiloBlu\Flow\Helper\Attribute $helperAttribute
     * @param \FiloBlu\Flow\Helper\LoggerProvider $loggerProvider
     * @param \Magento\Eav\Model\Entity\AttributeFactory $attributeFactory
     * @param \Magento\Eav\Model\ResourceModel\Entity\Attribute\Option\CollectionFactory $attributeOptionCollectionFactory
     * @param \Magento\Framework\ObjectManagerInterface $objectManager
     * @param \Magento\Eav\Model\ConfigFactory $configFactory
     * @param \Magento\Eav\Model\Entity\TypeFactory $entityTypeFactory
     * @param array $data
     */
    public function __construct(
        \Magento\Framework\Registry $registry,
        \Magento\Catalog\Model\ProductFactory $productFactory,
        \FiloBlu\Flow\Helper\Product $helperProduct,
        \FiloBlu\Flow\Helper\Attribute $helperAttribute,
        \FiloBlu\Flow\Helper\LoggerProvider $loggerProvider,
        \Magento\Eav\Model\Entity\AttributeFactory $attributeFactory,
        \Magento\Eav\Model\ResourceModel\Entity\Attribute\Option\CollectionFactory $attributeOptionCollectionFactory,
        \Magento\Framework\ObjectManagerInterface $objectManager,
        \Magento\Eav\Model\ConfigFactory $configFactory,
        \Magento\Eav\Model\Entity\TypeFactory $entityTypeFactory,
        array $data = []
    )
    {
        parent::__construct($registry,
            $productFactory,
            $helperProduct,
            $helperAttribute,
            $loggerProvider,
            $attributeFactory,
            $attributeOptionCollectionFactory,
            $objectManager,
            $entityTypeFactory,
            $data

        );
        $this->configFactory = $configFactory;
    }

    /**
     * @return mixed|null
     * @throws \Exception
     */
    protected function getObject()
    {

        if (is_null($this->objectEntity)) {
            /** @var \Magento\Eav\Model\Config $objectEntity */
            $objectEntity = $this->configFactory->create();
            $this->objectEntity = $objectEntity->getAttribute('catalog_product', $this->getObjectId());
        }
        if (!$this->getObjectId()) {
            throw new \Exception('No id found for model ' . $this->getEntityModel() . ' with given identifier ' . $this->entityIdentifier);
        }
        if ($this->entityTypeCode != 'product_attribute') {
            throw new \Exception('We don\'t manage ' . $this->entityTypeCode . ' attributes yet');
        }

        $this->objectEntity->setStoreId($this->storeId);


        if (!$this->objectEntity->getId()) {
            throw new \Exception('No instance found for model' . $this->getEntityModel() . ' with id ' . $this->getObjectId());
        }

        return $this->objectEntity;
    }


    /**
     * @return string|null
     */
    protected function getEntityModel()
    {
        if (is_null($this->entityTypeModel)) {
            $this->entityTypeModel = 'eav/entity_attribute';
        }

        return $this->entityTypeModel;
    }
}
